﻿using UnityEngine;
using UnityEngine.Experimental.Director;

public class PlayQueuePlayable : AnimationMixerPlayable
{
    public int m_CurrentClipIndex = -1;
    public float m_TimeToNextClip;

    public void PrepareFrame(FrameData info)
    {
        Playable[] inputs = GetInputs();

        // Advance to next clip if necessary
        m_TimeToNextClip -= (float)info.deltaTime;
        if (m_TimeToNextClip <= 0.0f)
        {
            m_CurrentClipIndex++;
            if (m_CurrentClipIndex < inputs.Length)
            {
                var currentClip = inputs[m_CurrentClipIndex] as AnimationClipPlayable;

                // Reset the time so that the next clip starts at the correct position
                inputs[m_CurrentClipIndex].time = 0;
                m_TimeToNextClip = currentClip.clip.length;
            }
            else
            {
                // Pause when queue is complete
                state = PlayState.Paused;
            }
        }

        // Adjust the weight of the inputs
        for (int a = 0; a < inputs.Length; a++)
        {
            if (a == m_CurrentClipIndex)
                SetInputWeight(a, 1.0f);
            else
                SetInputWeight(a, 0.0f);
        }
    }
}